@@ -1,5 +1,5 @@
 PROFILE_URL = 'https://cloudac.mildom.com/nonolive/gappserv/user/profileV2'
-PLAYBACK_LIST_URL = 'https://cloudac.mildom.com/nonolive/videocontent/profile/playbackList'
+PLAYBACK_LIST_URL = 'https://cloudac-cf-jp.mildom.com/nonolive/videocontent/profile/playbackList'
 
 CHAT_URL = 'https://cloudac.mildom.com/nonolive/videocontent/chat/replay'
 PLAYBACK_URL = 'https://cloudac.mildom.com/nonolive/videocontent/playback/getPlaybackDetail'
